embassy-usb

Crates

git

Versions

default

Flavors

Runner

Struct Runner 

pub struct Runner<'d, D: Driver<'d>> { /* private fields */ }
Background runner for the CDC-NCM class.

You must call .run() in a background task for the class to operate.

Implementations

Source

impl<'d, D: Driver<'d>> Runner<'d, D>

pub async fn run(self) -> !

Run the CDC-NCM class.

You must call this in a background task for the class to operate.